@@ -7,11 +7,32 @@
 #	Copyrights (c) 2014-2015 Mewsoft Corp. All rights reserved.
 #=========================================================#
 package Nile::Abort;
-#=========================================================#
+
+our $VERSION = '0.11';
+
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Nile::Abort - Abort the application at anytime with optional message and stacktrace.
+
+=head1 SYNOPSIS
+		
+	$self->me->abort("error message");
+
+	$self->me->abort("error title", "error message");
+
+=head1 DESCRIPTION
+
+Nile::Abort - Abort the application at anytime with optional message and stacktrace.
+
+=cut
+
 use Carp;# qw(croak shortmess longmess);
 use utf8;
 
-our $VERSION = '0.10';
 #=========================================================#
 sub abort {
 	my ($self) = shift;
@@ -59,4 +80,33 @@ HTML
 	exit 0;	
 }
 #=========================================================#
-1;
\ No newline at end of file
+
+=pod
+
+=head1 Bugs
+
+This project is available on github at L<https://github.com/mewsoft/Nile>.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Nile>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/mewsoft/Nile>.
+
+=head1 AUTHOR
+
+Ahmed Amin Elsheshtawy,  احمد امين الششتاوى <mewsoft@cpan.org>
+Website: http://www.mewsoft.com
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014-2015 by Dr. Ahmed Amin Elsheshtawy احمد امين الششتاوى mewsoft@cpan.org, support@mewsoft.com,
+L<https://github.com/mewsoft/Nile>, L<http://www.mewsoft.com>
+
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+=cut
+
+1;
