@@ -8,10 +8,28 @@
 #=========================================================#
 package Nile::XML;
 
+our $VERSION = '0.11';
+
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Nile::XML - XML file manager.
+
+=head1 SYNOPSIS
+		
+
+=head1 DESCRIPTION
+
+Nile::XML - XML file manager.
+
+=cut
+
 use Nile::Base;
 use XML::TreePP;
 
-our $VERSION = '0.10';
 #=========================================================#
 has 'xml' => (
 	is			=> 'rw',
@@ -168,4 +186,34 @@ sub add_file {
 sub DESTROY {
 }
 #=========================================================#
+
+=pod
+
+=head1 Bugs
+
+This project is available on github at L<https://github.com/mewsoft/Nile>.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Nile>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/mewsoft/Nile>.
+
+=head1 AUTHOR
+
+Ahmed Amin Elsheshtawy,  احمد امين الششتاوى <mewsoft@cpan.org>
+Website: http://www.mewsoft.com
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014-2015 by Dr. Ahmed Amin Elsheshtawy احمد امين الششتاوى mewsoft@cpan.org, support@mewsoft.com,
+L<https://github.com/mewsoft/Nile>, L<http://www.mewsoft.com>
+
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+=cut
+
 1;
+
